@@ -454,20 +454,13 @@ IDLUnion::member_impl_arg_copy (ostream          &ostr,
 	     << "_par_" << cpp_id << ";" << endl;
 }
 
-void
-IDLUnion::member_init_cpp (ostream          &ostr,
-			   Indent           &indent,
-			   const string     &cpp_id,
-			   const IDLTypedef *active_typedef) const
-{
-}
-
 void
 IDLUnion::member_init_c (ostream          &ostr,
 			 Indent           &indent,
 			 const string     &c_id,
 			 const IDLTypedef *active_typedef) const
 {
+#warning WRITEME
 }
 
 void
