@@ -33,7 +33,8 @@
 
 class IDLUserDefScopeType
 : public IDLScope,
-  public virtual IDLType
+  public virtual IDLType,
+  public IDLScopeTypeImplementation
 {
 public:
 	IDLUserDefScopeType(string const &id,IDL_tree node,IDLScope *parentscope = NULL, ReplaceType update = no_replace)
